==> dde-launchpad_1.99.9.tar.xz: BUILD/shell-launcher-applet/translations/org.deepin.ds.dock.launcherapplet_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="34"/>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="46"/>
        <source>Pin to Top</source>
        <translation>Przypnij na górze</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="55"/>
        <source>Move to Top</source>
        <translation>Przesuń na górę</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="65"/>
        <source>Remove from favorites</source>
        <translation>Usuń z ulubionych</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="65"/>
        <source>Add to favorites</source>
        <translation>Dodaj do ulubionych</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="80"/>
        <source>Send to desktop</source>
        <translation>Wyślij na pulpit</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="80"/>
        <source>Remove from desktop</source>
        <translation>Usuń z pulpitu</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="91"/>
        <source>Remove from dock</source>
        <translation>Usuń z doku</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="91"/>
        <source>Send to dock</source>
        <translation>Dodaj do doku</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="103"/>
        <source>Add to startup</source>
        <translation>Dodaj do uruchamiania</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="103"/>
        <source>Remove from startup</source>
        <translation>Usuń z uruchamiania</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="111"/>
        <source>Use a proxy</source>
        <translation>Użyj Proxy</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="120"/>
        <source>Disable display scaling</source>
        <translation>Wyłącz skalowanie wyświetlacza</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="127"/>
        <source>Uninstall</source>
        <translation>Odinstaluj</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="32"/>
        <source>Power</source>
        <translation>Zasilanie</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="58"/>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="105"/>
        <source>Full-screen Mode</source>
        <translation>Tryb pełnoekranowy</translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <location filename="../../qml/DummyAppItemMenu.qml" line="27"/>
        <source>Install</source>
        <translation>Zainstaluj</translation>
    </message>
    <message>
        <location filename="../../qml/DummyAppItemMenu.qml" line="34"/>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../../qml/windowed/FrequentlyUsedView.qml" line="36"/>
        <source>Frequently Used</source>
        <translation>Często używane</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <location filename="../../qml/FullscreenFrame.qml" line="152"/>
        <source>Window Mode</source>
        <translation>Tryb okna</translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation>Pokaż program uruchamiający (domyślnie ukryty)</translation>
    </message>
    <message>
        <location filename="../../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation>Przełącz widoczność programu uruchamiającego</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../../qml/Main.qml" line="22"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="24"/>
        <source>Chat</source>
        <translation>Rozmowy</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="26"/>
        <source>Music</source>
        <translation>Muzyka</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="28"/>
        <source>Video</source>
        <translation>Wideo</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="30"/>
        <source>Graphics</source>
        <translation>Grafika</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="32"/>
        <source>Game</source>
        <translation>Gry</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="34"/>
        <source>Office</source>
        <translation>Biuro</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="36"/>
        <source>Reading</source>
        <translation>Czytanie</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="38"/>
        <source>Development</source>
        <translation>Programowanie</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="40"/>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="42"/>
        <source>Others</source>
        <translation>Inne</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="411"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>Czy na pewno chcesz odinstalować %1?</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="423"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="437"/>
        <source>Confirm</source>
        <translation>Potwierdź</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../../qml/windowed/RecentlyInstalledView.qml" line="34"/>
        <source>Recently Installed</source>
        <translation>Ostatnio zainstalowane</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../../qml/windowed/SearchResultView.qml" line="37"/>
        <source>All Apps</source>
        <translation>Wszystkie aplikacje</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SearchResultView.qml" line="102"/>
        <location filename="../../qml/FullscreenFrame.qml" line="545"/>
        <source>No search results</source>
        <translation>Brak wyników wyszukiwania</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="40"/>
        <source>Free sorting</source>
        <translation>Sortowanie swobodne</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="54"/>
        <source>Sort by category</source>
        <translation>Sortuj według kategorii</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="66"/>
        <source>Sort by name</source>
        <translation>Sortuj według nazwy</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="90"/>
        <source>Sorting Mode</source>
        <translation>Tryb sortowania</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="145"/>
        <source>Computer</source>
        <translation>Komputer</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="156"/>
        <source>Pictures</source>
        <translation>Obrazy</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="167"/>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="178"/>
        <source>Desktop</source>
        <translation>Pulpit</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="189"/>
        <source>Control Center</source>
        <translation>Centrum sterowania</translation>
    </message>
</context>
<context>
    <name>launcheritem</name>
    <message>
        <location filename="../package/launcheritem.qml" line="110"/>
        <source>Internet</source>
        <translation type="unfinished">Internet</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="112"/>
        <source>Chat</source>
        <translation type="unfinished">Rozmowy</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="114"/>
        <source>Music</source>
        <translation type="unfinished">Muzyka</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="116"/>
        <source>Video</source>
        <translation type="unfinished">Wideo</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="118"/>
        <source>Graphics</source>
        <translation type="unfinished">Grafika</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="120"/>
        <source>Game</source>
        <translation type="unfinished">Gry</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="122"/>
        <source>Office</source>
        <translation type="unfinished">Biuro</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="124"/>
        <source>Reading</source>
        <translation type="unfinished">Czytanie</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="126"/>
        <source>Development</source>
        <translation type="unfinished">Programowanie</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="128"/>
        <source>System</source>
        <translation type="unfinished">System</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="130"/>
        <source>Others</source>
        <translation type="unfinished">Inne</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="140"/>
        <source>launchpad</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="268"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation type="unfinished">Czy na pewno chcesz odinstalować %1?</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="280"/>
        <source>Cancel</source>
        <translation type="unfinished">Anuluj</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="294"/>
        <source>Confirm</source>
        <translation type="unfinished">Potwierdź</translation>
    </message>
</context>
</TS>

==> dde-launchpad_1.99.10.tar.xz: BUILD/shell-launcher-applet/translations/org.deepin.ds.dock.launcherapplet_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="34"/>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="46"/>
        <source>Pin to Top</source>
        <translation>Przypnij na górze</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="55"/>
        <source>Move to Top</source>
        <translation>Przenieś na górę</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="65"/>
        <source>Remove from favorites</source>
        <translation>Usuń z ulubionych</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="65"/>
        <source>Add to favorites</source>
        <translation>Dodaj do ulubionych</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="80"/>
        <source>Remove from desktop</source>
        <translation>Usuń z pulpitu</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="80"/>
        <source>Send to desktop</source>
        <translation>Wyślij na pulpit</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="91"/>
        <source>Remove from dock</source>
        <translation>Usuń z doku</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="91"/>
        <source>Send to dock</source>
        <translation>Dodaj do doku</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="103"/>
        <source>Remove from startup</source>
        <translation>Usuń z startu systemu</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="103"/>
        <source>Add to startup</source>
        <translation>Dodaj do startu systemu</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="111"/>
        <source>Use a proxy</source>
        <translation>Użyj proxy</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="120"/>
        <source>Disable display scaling</source>
        <translation>Wyłącz skalowanie wyświetlacza</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="127"/>
        <source>Uninstall</source>
        <translation>Odinstaluj</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="33"/>
        <source>Power</source>
        <translation>Zasilanie</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="62"/>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="109"/>
        <source>Full-screen Mode</source>
        <translation>Tryb pełnoekranowy</translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <location filename="../../qml/DummyAppItemMenu.qml" line="27"/>
        <source>Install</source>
        <translation>Zainstaluj</translation>
    </message>
    <message>
        <location filename="../../qml/DummyAppItemMenu.qml" line="34"/>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../../qml/windowed/FrequentlyUsedView.qml" line="36"/>
        <source>Frequently Used</source>
        <translation>Często używane</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <location filename="../../qml/FullscreenFrame.qml" line="163"/>
        <source>Window Mode</source>
        <translation>Tryb okna</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../../qml/Main.qml" line="22"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="24"/>
        <source>Chat</source>
        <translation>Rozmowy</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="26"/>
        <source>Music</source>
        <translation>Muzyka</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="28"/>
        <source>Video</source>
        <translation>Wideo</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="30"/>
        <source>Graphics</source>
        <translation>Grafika</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="32"/>
        <source>Games</source>
        <translation>Gry</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="34"/>
        <source>Office</source>
        <translation>Biuro</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="36"/>
        <source>Reading</source>
        <translation>Czytanie</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="38"/>
        <source>Development</source>
        <translation>Programowanie</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="40"/>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="42"/>
        <source>Others</source>
        <translation>Inne</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="400"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>Czy na pewno chcesz odinstalować %1?</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="412"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="426"/>
        <source>Confirm</source>
        <translation>Potwierdź</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../../qml/windowed/RecentlyInstalledView.qml" line="34"/>
        <source>Recently Installed</source>
        <translation>Ostatnio zainstalowane</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../../qml/windowed/SearchResultView.qml" line="37"/>
        <source>All Apps</source>
        <translation>Wszystkie aplikacje</translation>
    </message>
    <message>
        <location filename="../../qml/FullscreenFrame.qml" line="556"/>
        <location filename="../../qml/windowed/SearchResultView.qml" line="102"/>
        <source>No search results</source>
        <translation>Brak wyników wyszukiwania</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="40"/>
        <source>Free sorting</source>
        <translation>Sortowanie swobodne</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="54"/>
        <source>Sort by category</source>
        <translation>Sortuj wg. kategorii</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="66"/>
        <source>Sort by name</source>
        <translation>Sortuj wg. nazwy</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="90"/>
        <source>Sorting Mode</source>
        <translation>Tryb sortowania</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="145"/>
        <source>Computer</source>
        <translation>Komputer</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="156"/>
        <source>Pictures</source>
        <translation>Zdjęcia</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="167"/>
        <source>Documents</source>
        <translation>Dokumenty</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="178"/>
        <source>Desktop</source>
        <translation>Pulpit</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="189"/>
        <source>Control Center</source>
        <translation>Centrum kontroli</translation>
    </message>
</context>
<context>
    <name>launcheritem</name>
    <message>
        <location filename="../package/launcheritem.qml" line="111"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="113"/>
        <source>Chat</source>
        <translation>Komunikacja</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="115"/>
        <source>Music</source>
        <translation>Muzyka</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="117"/>
        <source>Video</source>
        <translation>Wideo</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="119"/>
        <source>Graphics</source>
        <translation>Grafika</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="121"/>
        <source>Games</source>
        <translation>Gry</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="123"/>
        <source>Office</source>
        <translation>Biurowe</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="125"/>
        <source>Reading</source>
        <translation>Czytanie</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="127"/>
        <source>Development</source>
        <translation>Programowanie</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="129"/>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="131"/>
        <source>Others</source>
        <translation>Inne</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="162"/>
        <source>launchpad</source>
        <translation>Launchpad</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="299"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>Czy na pewno chcesz odinstalować %1?</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="311"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="325"/>
        <source>Confirm</source>
        <translation>Potwierdź</translation>
    </message>
</context>
</TS>
